@@ -1,13 +1,16 @@
 package if;
 
-$VERSION = '0.01000001';
+$VERSION = '0.04';
 
 sub work {
   my $method = shift() ? 'import' : 'unimport';
   return unless shift;		# CONDITION
-  my $p = shift;		# PACKAGE
-  eval "require $p" or die;	# Adds .pm etc if needed
-  $p->$method(@_) if $p->can($method);
+
+  my $p = $_[0];		# PACKAGE
+  (my $file = "$p.pm") =~ s!::!/!g;
+  require $file;		# Works even if $_[0] is a keyword (like open)
+  my $m = $p->can($method);
+  goto &$m if $m;
 }
 
 sub import   { shift; unshift @_, 1; goto &work }
